@@ -104,10 +104,10 @@ final readonly class StatsAjaxHandler implements AjaxHandlerInterface
                 show_now_playing();
                 $results['now_playing'] = ob_get_clean();
                 ob_start();
-                $user_only  = (isset($_REQUEST['user_id']))
+                $user_id = (isset($_REQUEST['user_id']))
                     ? (int)$this->requestParser->getFromRequest('user_id')
                     : $user->id ?? -1;
-                $user_id    = $user->id;
+                $user_only  = isset($_REQUEST['user_only']);
                 $ajax_page  = 'stats';
                 if (AmpConfig::get('home_recently_played_all')) {
                     $data = Stats::get_recently_played($user_id, 'stream', null, $user_only);
@@ -133,7 +133,7 @@ final readonly class StatsAjaxHandler implements AjaxHandlerInterface
                 show_now_playing();
                 $results['now_playing'] = ob_get_clean();
                 ob_start();
-                $user_id    = (isset($_REQUEST['user_id']))
+                $user_id = (isset($_REQUEST['user_id']))
                     ? (int)$this->requestParser->getFromRequest('user_id')
                     : $user->id ?? -1;
                 $user_only  = isset($_REQUEST['user_only']);
