@@ -288,7 +288,6 @@ class AmpacheVlc extends localplay_controller
      * delete_track
      * This must take an array of ID's (as passed by get function) from Ampache
      * and delete them from VLC webinterface
-     * @param int $object_id
      */
     public function delete_track(int $object_id): bool
     {
@@ -432,8 +431,7 @@ class AmpacheVlc extends localplay_controller
     /**
      * volume
      * This tells VLC to set the volume to the specified amount this
-     * is 0-400 procent
-     * @param $volume
+     * is 0-400 percent
      */
     public function volume($volume): bool
     {
@@ -531,9 +529,8 @@ class AmpacheVlc extends localplay_controller
             $url_data = $this->parse_url($entry);
             switch ($url_data['primary_key']) {
                 case 'oid':
-                    $data['oid'] = $url_data['oid'];
-                    $song        = new Song($data['oid']);
-                    $song->format();
+                    $data['oid']  = $url_data['oid'];
+                    $song         = new Song($data['oid']);
                     $data['name'] = $song->get_fullname() . ' - ' . $song->get_album_fullname($song->album, true) . ' - ' . $song->get_artist_fullname();
                     $data['link'] = $song->get_f_link();
                     break;
@@ -549,9 +546,9 @@ class AmpacheVlc extends localplay_controller
                 default:
                     // If we don't know it, look up by filename
                     $filename = Dba::escape($entry);
-                    $sql      = "SELECT `name` FROM `live_stream` WHERE `url`='$filename' ";
+                    $sql      = "SELECT `name` FROM `live_stream` WHERE `url` = ? ";
 
-                    $db_results = Dba::read($sql);
+                    $db_results = Dba::read($sql, [$filename]);
                     if ($row = Dba::fetch_assoc($db_results)) {
                         // if stream is known just send name
                         $data['name'] = htmlspecialchars(substr($row['name'], 0, 50));
