@@ -246,7 +246,7 @@ class Rating extends database_object
     {
         $type    = Stats::validate_type($input_type);
         $user_id = (int)($user_id ?? -1);
-        $sql     = "SELECT MAX(`rating`.`id`) AS `table_id`, MIN(`rating`.`object_id`) AS `id`, ROUND(AVG(`rating`.`rating`), 2) AS `rating`, COUNT(DISTINCT(`rating`.`user`)) AS `count` FROM `rating`";
+        $sql     = "SELECT MAX(`rating`.`id`) AS `table_id`, MIN(`rating`.`object_id`) AS `id`, ROUND(AVG(`rating`.`rating`), 2) AS `rating`, COUNT(DISTINCT(`rating`.`user`)) AS `count`, MAX(`rating`.`date`) AS `date` FROM `rating`";
         if ($input_type == 'album_artist' || $input_type == 'song_artist') {
             $sql .= " LEFT JOIN `artist` ON `artist`.`id` = `rating`.`object_id` AND `rating`.`object_type` = 'artist'";
         }
@@ -270,7 +270,7 @@ class Rating extends database_object
 
         //debug_event(self::class, 'get_highest_sql ' . $sql, 5);
 
-        return $sql . " GROUP BY `rating`.`object_id` ORDER BY `rating` DESC, `count` DESC, `table_id` DESC ";
+        return $sql . " GROUP BY `rating`.`object_id` ORDER BY `rating` DESC, `date` DESC, `count` DESC, `table_id` DESC ";
     }
 
     /**
