@@ -1133,7 +1133,8 @@ class User extends database_object
     {
         // don't do anything if it's formatted
         if ($this->link === null && $this->id > 0) {
-            $web_path   = AmpConfig::get_web_path();
+            $web_path = AmpConfig::get_web_path();
+
             $this->link = $web_path . '/stats.php?action=show_user&user_id=' . $this->id;
         }
 
@@ -1264,7 +1265,7 @@ class User extends database_object
 
         $art = new Art($this->id, 'user');
 
-        return $art->insert($data, $mime);
+        return ($art->insert($data, $mime) === true);
     }
 
     /**
